# Auto-generated. Do not modify, use scripts/generate_langs.py instead.
AFRIKAANS = "Afrikaans"
AMHARIC = "Amharic"
ARABIC = "Arabic"
ASTURIAN = "Asturian"
AZERBAIJANI = "Azerbaijani"
BASHKIR = "Bashkir"
BELARUSIAN = "Belarusian"
BULGARIAN = "Bulgarian"
BENGALI = "Bengali"
BRETON = "Breton"
BOSNIAN = "Bosnian"
CATALAN = "Catalan"
VALENCIAN = "Valencian"
CEBUANO = "Cebuano"
CZECH = "Czech"
WELSH = "Welsh"
DANISH = "Danish"
GERMAN = "German"
GREEK = "Greek"
ENGLISH = "English"
SPANISH = "Spanish"
ESTONIAN = "Estonian"
PERSIAN = "Persian"
FULAH = "Fulah"
FINNISH = "Finnish"
FRENCH = "French"
WESTERN_FRISIAN = "Western Frisian"
IRISH = "Irish"
GAELIC = "Gaelic"
SCOTTISH_GAELIC = "Scottish Gaelic"
GALICIAN = "Galician"
GUJARATI = "Gujarati"
HAUSA = "Hausa"
HEBREW = "Hebrew"
HINDI = "Hindi"
CROATIAN = "Croatian"
HAITIAN = "Haitian"
HAITIAN_CREOLE = "Haitian Creole"
HUNGARIAN = "Hungarian"
ARMENIAN = "Armenian"
INDONESIAN = "Indonesian"
IGBO = "Igbo"
ILOKO = "Iloko"
ICELANDIC = "Icelandic"
ITALIAN = "Italian"
JAPANESE = "Japanese"
JAVANESE = "Javanese"
GEORGIAN = "Georgian"
KAZAKH = "Kazakh"
CENTRAL_KHMER = "Central Khmer"
KANNADA = "Kannada"
KOREAN = "Korean"
LUXEMBOURGISH = "Luxembourgish"
LETZEBURGESCH = "Letzeburgesch"
GANDA = "Ganda"
LINGALA = "Lingala"
LAO = "Lao"
LITHUANIAN = "Lithuanian"
LATVIAN = "Latvian"
MALAGASY = "Malagasy"
MACEDONIAN = "Macedonian"
MALAYALAM = "Malayalam"
MONGOLIAN = "Mongolian"
MARATHI = "Marathi"
MALAY = "Malay"
BURMESE = "Burmese"
NEPALI = "Nepali"
DUTCH = "Dutch"
FLEMISH = "Flemish"
NORWEGIAN = "Norwegian"
NORTHERN_SOTHO = "Northern Sotho"
OCCITAN = "Occitan"
ORIYA = "Oriya"
PANJABI = "Panjabi"
PUNJABI = "Punjabi"
POLISH = "Polish"
PUSHTO = "Pushto"
PASHTO = "Pashto"
PORTUGUESE = "Portuguese"
ROMANIAN = "Romanian"
MOLDAVIAN = "Moldavian"
MOLDOVAN = "Moldovan"
RUSSIAN = "Russian"
SINDHI = "Sindhi"
SINHALA = "Sinhala"
SINHALESE = "Sinhalese"
SLOVAK = "Slovak"
SLOVENIAN = "Slovenian"
SOMALI = "Somali"
ALBANIAN = "Albanian"
SERBIAN = "Serbian"
SWATI = "Swati"
SUNDANESE = "Sundanese"
SWEDISH = "Swedish"
SWAHILI = "Swahili"
TAMIL = "Tamil"
THAI = "Thai"
TAGALOG = "Tagalog"
TSWANA = "Tswana"
TURKISH = "Turkish"
UKRAINIAN = "Ukrainian"
URDU = "Urdu"
UZBEK = "Uzbek"
VIETNAMESE = "Vietnamese"
WOLOF = "Wolof"
XHOSA = "Xhosa"
YIDDISH = "Yiddish"
YORUBA = "Yoruba"
CHINESE = "Chinese"
ZULU = "Zulu"
