# Auto-generated. Do not modify, use scripts/generate_langs.py instead.
ARABIC = "Arabic"
CZECH = "Czech"
GERMAN = "German"
ENGLISH = "English"
SPANISH = "Spanish"
ESTONIAN = "Estonian"
FINNISH = "Finnish"
FRENCH = "French"
GUJARATI = "Gujarati"
HINDI = "Hindi"
ITALIAN = "Italian"
JAPANESE = "Japanese"
KAZAKH = "Kazakh"
KOREAN = "Korean"
LITHUANIAN = "Lithuanian"
LATVIAN = "Latvian"
BURMESE = "Burmese"
NEPALI = "Nepali"
DUTCH = "Dutch"
ROMANIAN = "Romanian"
RUSSIAN = "Russian"
SINHALA = "Sinhala"
TURKISH = "Turkish"
VIETNAMESE = "Vietnamese"
CHINESE = "Chinese"
AFRIKAANS = "Afrikaans"
AZERBAIJANI = "Azerbaijani"
BENGALI = "Bengali"
PERSIAN = "Persian"
HEBREW = "Hebrew"
CROATIAN = "Croatian"
INDONESIAN = "Indonesian"
GEORGIAN = "Georgian"
KHMER = "Khmer"
MACEDONIAN = "Macedonian"
MALAYALAM = "Malayalam"
MONGOLIAN = "Mongolian"
MARATHI = "Marathi"
POLISH = "Polish"
PASHTO = "Pashto"
PORTUGUESE = "Portuguese"
SWEDISH = "Swedish"
SWAHILI = "Swahili"
TAMIL = "Tamil"
TELUGU = "Telugu"
THAI = "Thai"
TAGALOG = "Tagalog"
UKRAINIAN = "Ukrainian"
URDU = "Urdu"
XHOSA = "Xhosa"
GALICIAN = "Galician"
SLOVENE = "Slovene"
