# Auto-generated. Do not modify, use scripts/generate_langs.py instead.
_PAIRS_M2M100 = (
    ("Afrikaans", "af"),
    ("Amharic", "am"),
    ("Arabic", "ar"),
    ("Asturian", "ast"),
    ("Azerbaijani", "az"),
    ("Bashkir", "ba"),
    ("Belarusian", "be"),
    ("Bulgarian", "bg"),
    ("Bengali", "bn"),
    ("Breton", "br"),
    ("Bosnian", "bs"),
    ("Catalan", "ca"),
    ("Valencian", "ca"),
    ("Cebuano", "ceb"),
    ("Czech", "cs"),
    ("Welsh", "cy"),
    ("Danish", "da"),
    ("German", "de"),
    ("Greek", "el"),
    ("English", "en"),
    ("Spanish", "es"),
    ("Estonian", "et"),
    ("Persian", "fa"),
    ("Fulah", "ff"),
    ("Finnish", "fi"),
    ("French", "fr"),
    ("Western Frisian", "fy"),
    ("Irish", "ga"),
    ("Gaelic", "gd"),
    ("Scottish Gaelic", "gd"),
    ("Galician", "gl"),
    ("Gujarati", "gu"),
    ("Hausa", "ha"),
    ("Hebrew", "he"),
    ("Hindi", "hi"),
    ("Croatian", "hr"),
    ("Haitian", "ht"),
    ("Haitian Creole", "ht"),
    ("Hungarian", "hu"),
    ("Armenian", "hy"),
    ("Indonesian", "id"),
    ("Igbo", "ig"),
    ("Iloko", "ilo"),
    ("Icelandic", "is"),
    ("Italian", "it"),
    ("Japanese", "ja"),
    ("Javanese", "jv"),
    ("Georgian", "ka"),
    ("Kazakh", "kk"),
    ("Central Khmer", "km"),
    ("Kannada", "kn"),
    ("Korean", "ko"),
    ("Luxembourgish", "lb"),
    ("Letzeburgesch", "lb"),
    ("Ganda", "lg"),
    ("Lingala", "ln"),
    ("Lao", "lo"),
    ("Lithuanian", "lt"),
    ("Latvian", "lv"),
    ("Malagasy", "mg"),
    ("Macedonian", "mk"),
    ("Malayalam", "ml"),
    ("Mongolian", "mn"),
    ("Marathi", "mr"),
    ("Malay", "ms"),
    ("Burmese", "my"),
    ("Nepali", "ne"),
    ("Dutch", "nl"),
    ("Flemish", "nl"),
    ("Norwegian", "no"),
    ("Northern Sotho", "ns"),
    ("Occitan", "oc"),
    ("Oriya", "or"),
    ("Panjabi", "pa"),
    ("Punjabi", "pa"),
    ("Polish", "pl"),
    ("Pushto", "ps"),
    ("Pashto", "ps"),
    ("Portuguese", "pt"),
    ("Romanian", "ro"),
    ("Moldavian", "ro"),
    ("Moldovan", "ro"),
    ("Russian", "ru"),
    ("Sindhi", "sd"),
    ("Sinhala", "si"),
    ("Sinhalese", "si"),
    ("Slovak", "sk"),
    ("Slovenian", "sl"),
    ("Somali", "so"),
    ("Albanian", "sq"),
    ("Serbian", "sr"),
    ("Swati", "ss"),
    ("Sundanese", "su"),
    ("Swedish", "sv"),
    ("Swahili", "sw"),
    ("Tamil", "ta"),
    ("Thai", "th"),
    ("Tagalog", "tl"),
    ("Tswana", "tn"),
    ("Turkish", "tr"),
    ("Ukrainian", "uk"),
    ("Urdu", "ur"),
    ("Uzbek", "uz"),
    ("Vietnamese", "vi"),
    ("Wolof", "wo"),
    ("Xhosa", "xh"),
    ("Yiddish", "yi"),
    ("Yoruba", "yo"),
    ("Chinese", "zh"),
    ("Zulu", "zu"),
)
_PAIRS_MBART50 = (
    ("Arabic", "ar_AR"),
    ("Czech", "cs_CZ"),
    ("German", "de_DE"),
    ("English", "en_XX"),
    ("Spanish", "es_XX"),
    ("Estonian", "et_EE"),
    ("Finnish", "fi_FI"),
    ("French", "fr_XX"),
    ("Gujarati", "gu_IN"),
    ("Hindi", "hi_IN"),
    ("Italian", "it_IT"),
    ("Japanese", "ja_XX"),
    ("Kazakh", "kk_KZ"),
    ("Korean", "ko_KR"),
    ("Lithuanian", "lt_LT"),
    ("Latvian", "lv_LV"),
    ("Burmese", "my_MM"),
    ("Nepali", "ne_NP"),
    ("Dutch", "nl_XX"),
    ("Romanian", "ro_RO"),
    ("Russian", "ru_RU"),
    ("Sinhala", "si_LK"),
    ("Turkish", "tr_TR"),
    ("Vietnamese", "vi_VN"),
    ("Chinese", "zh_CN"),
    ("Afrikaans", "af_ZA"),
    ("Azerbaijani", "az_AZ"),
    ("Bengali", "bn_IN"),
    ("Persian", "fa_IR"),
    ("Hebrew", "he_IL"),
    ("Croatian", "hr_HR"),
    ("Indonesian", "id_ID"),
    ("Georgian", "ka_GE"),
    ("Khmer", "km_KH"),
    ("Macedonian", "mk_MK"),
    ("Malayalam", "ml_IN"),
    ("Mongolian", "mn_MN"),
    ("Marathi", "mr_IN"),
    ("Polish", "pl_PL"),
    ("Pashto", "ps_AF"),
    ("Portuguese", "pt_XX"),
    ("Swedish", "sv_SE"),
    ("Swahili", "sw_KE"),
    ("Tamil", "ta_IN"),
    ("Telugu", "te_IN"),
    ("Thai", "th_TH"),
    ("Tagalog", "tl_XX"),
    ("Ukrainian", "uk_UA"),
    ("Urdu", "ur_PK"),
    ("Xhosa", "xh_ZA"),
    ("Galician", "gl_ES"),
    ("Slovene", "sl_SI"),
)
